@@ -50,9 +50,9 @@ def handle_channels_cb(handler, account, connection, channels, requests,
 if __name__ == '__main__':
     #TelepathyGLib.debug_set_flags("all")
 
-    dbus = TelepathyGLib.DBusDaemon.dup()
+    am = TelepathyGLib.AccountManager.dup()
 
-    handler = TelepathyGLib.SimpleHandler.new(dbus, False, False,
+    handler = TelepathyGLib.SimpleHandler.new_with_am(am, False, False,
         'ExampleHandler', False, handle_channels_cb, None)
 
     handler.add_handler_filter({
