@@ -18,6 +18,7 @@
 #include <dbus/dbus-glib.h>
 
 #include <telepathy-glib/dbus.h>
+#include <telepathy-glib/dbus-properties-mixin.h>
 #include <telepathy-glib/errors.h>
 #include <telepathy-glib/gtypes.h>
 #include <telepathy-glib/handle-repo-dynamic.h>
@@ -28,10 +29,12 @@
 #include "room-list-chan.h"
 #include "util.h"
 
+static void props_iface_init (TpSvcDBusPropertiesClass *);
 static void conn_iface_init (TpSvcConnectionClass *);
 
 G_DEFINE_TYPE_WITH_CODE (TpTestsSimpleConnection, tp_tests_simple_connection,
     TP_TYPE_BASE_CONNECTION,
+    G_IMPLEMENT_INTERFACE (TP_TYPE_SVC_DBUS_PROPERTIES, props_iface_init);
     G_IMPLEMENT_INTERFACE (TP_TYPE_SVC_CONNECTION, conn_iface_init))
 
 /* type definition stuff */
@@ -47,6 +50,7 @@ enum
 enum
 {
   SIGNAL_GOT_SELF_HANDLE,
+  SIGNAL_GOT_ALL,
   N_SIGNALS
 };
 
@@ -344,6 +348,13 @@ tp_tests_simple_connection_class_init (TpTestsSimpleConnectionClass *klass)
       0,
       NULL, NULL, NULL,
       G_TYPE_NONE, 0);
+
+  signals[SIGNAL_GOT_ALL] = g_signal_new ("got-all",
+      G_OBJECT_CLASS_TYPE (klass),
+      G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
+      0,
+      NULL, NULL, NULL,
+      G_TYPE_NONE, 0);
 }
 
 void
@@ -507,3 +518,26 @@ conn_iface_init (TpSvcConnectionClass *iface)
   IMPLEMENT(,get_self_handle);
 #undef IMPLEMENT
 }
+
+static void
+get_all (TpSvcDBusProperties *iface,
+    const gchar *interface_name,
+    DBusGMethodInvocation *context)
+{
+  GHashTable *values = tp_dbus_properties_mixin_dup_all (G_OBJECT (iface),
+      interface_name);
+
+  tp_svc_dbus_properties_return_from_get_all (context, values);
+  g_hash_table_unref (values);
+  g_signal_emit (iface, signals[SIGNAL_GOT_ALL],
+      g_quark_from_string (interface_name));
+}
+
+static void
+props_iface_init (TpSvcDBusPropertiesClass *iface)
+{
+#define IMPLEMENT(x) \
+  tp_svc_dbus_properties_implement_##x (iface, x)
+  IMPLEMENT (get_all);
+#undef IMPLEMENT
+}
